@@ -8,7 +8,6 @@ import numpy as np
 from gym import Env, spaces, utils
 from gym.envs.toy_text.utils import categorical_sample
 from gym.error import DependencyNotInstalled
-from gym.utils.renderer import Renderer
 
 LEFT = 0
 DOWN = 1
@@ -156,7 +155,7 @@ class FrozenLakeEnv(Env):
     """
 
     metadata = {
-        "render_modes": ["human", "ansi", "rgb_array", "single_rgb_array"],
+        "render_modes": ["human", "ansi", "rgb_array"],
         "render_fps": 4,
     }
 
@@ -226,10 +225,13 @@ class FrozenLakeEnv(Env):
         self.action_space = spaces.Discrete(nA)
 
         self.render_mode = render_mode
-        self.renderer = Renderer(self.render_mode, self._render)
 
         # pygame utils
         self.window_size = (min(64 * ncol, 512), min(64 * nrow, 512))
+        self.cell_size = (
+            self.window_size[0] // self.ncol,
+            self.window_size[1] // self.nrow,
+        )
         self.window_surface = None
         self.clock = None
         self.hole_img = None
@@ -245,40 +247,30 @@ class FrozenLakeEnv(Env):
         p, s, r, t = transitions[i]
         self.s = s
         self.lastaction = a
-        self.renderer.render_step()
+
+        if self.render_mode == "human":
+            self.render()
         return (int(s), r, t, False, {"prob": p})
 
     def reset(
         self,
         *,
         seed: Optional[int] = None,
-        return_info: bool = False,
         options: Optional[dict] = None,
     ):
         super().reset(seed=seed)
         self.s = categorical_sample(self.initial_state_distrib, self.np_random)
         self.lastaction = None
 
-        self.renderer.reset()
-        self.renderer.render_step()
+        if self.render_mode == "human":
+            self.render()
+        return int(self.s), {"prob": 1}
 
-        if not return_info:
-            return int(self.s)
-        else:
-            return int(self.s), {"prob": 1}
-
-    def render(self, mode="human"):
-        if self.render_mode is not None:
-            return self.renderer.get_renders()
-        else:
-            return self._render(mode)
-
-    def _render(self, mode="human"):
-        assert mode in self.metadata["render_modes"]
-        if mode == "ansi":
+    def render(self):
+        if self.render_mode == "ansi":
             return self._render_text()
-        elif mode in {"human", "rgb_array", "single_rgb_array"}:
-            return self._render_gui(mode)
+        else:  # self.render_mode in {"human", "rgb_array"}:
+            return self._render_gui(self.render_mode)
 
     def _render_gui(self, mode):
         try:
@@ -290,11 +282,12 @@ class FrozenLakeEnv(Env):
 
         if self.window_surface is None:
             pygame.init()
-            pygame.display.init()
-            pygame.display.set_caption("Frozen Lake")
+
             if mode == "human":
+                pygame.display.init()
+                pygame.display.set_caption("Frozen Lake")
                 self.window_surface = pygame.display.set_mode(self.window_size)
-            elif mode in {"rgb_array", "single_rgb_array"}:
+            elif mode == "rgb_array":
                 self.window_surface = pygame.Surface(self.window_size)
 
         assert (
@@ -305,19 +298,29 @@ class FrozenLakeEnv(Env):
             self.clock = pygame.time.Clock()
         if self.hole_img is None:
             file_name = path.join(path.dirname(__file__), "img/hole.png")
-            self.hole_img = pygame.image.load(file_name)
+            self.hole_img = pygame.transform.scale(
+                pygame.image.load(file_name), self.cell_size
+            )
         if self.cracked_hole_img is None:
             file_name = path.join(path.dirname(__file__), "img/cracked_hole.png")
-            self.cracked_hole_img = pygame.image.load(file_name)
+            self.cracked_hole_img = pygame.transform.scale(
+                pygame.image.load(file_name), self.cell_size
+            )
         if self.ice_img is None:
             file_name = path.join(path.dirname(__file__), "img/ice.png")
-            self.ice_img = pygame.image.load(file_name)
+            self.ice_img = pygame.transform.scale(
+                pygame.image.load(file_name), self.cell_size
+            )
         if self.goal_img is None:
             file_name = path.join(path.dirname(__file__), "img/goal.png")
-            self.goal_img = pygame.image.load(file_name)
+            self.goal_img = pygame.transform.scale(
+                pygame.image.load(file_name), self.cell_size
+            )
         if self.start_img is None:
             file_name = path.join(path.dirname(__file__), "img/stool.png")
-            self.start_img = pygame.image.load(file_name)
+            self.start_img = pygame.transform.scale(
+                pygame.image.load(file_name), self.cell_size
+            )
         if self.elf_images is None:
             elfs = [
                 path.join(path.dirname(__file__), "img/elf_left.png"),
@@ -325,73 +328,44 @@ class FrozenLakeEnv(Env):
                 path.join(path.dirname(__file__), "img/elf_right.png"),
                 path.join(path.dirname(__file__), "img/elf_up.png"),
             ]
-            self.elf_images = [pygame.image.load(f_name) for f_name in elfs]
-
-        cell_width = self.window_size[0] // self.ncol
-        cell_height = self.window_size[1] // self.nrow
-        smaller_cell_scale = 0.6
-        small_cell_w = int(smaller_cell_scale * cell_width)
-        small_cell_h = int(smaller_cell_scale * cell_height)
-
-        # prepare images
-        last_action = self.lastaction if self.lastaction is not None else 1
-        elf_img = self.elf_images[last_action]
-        elf_scale = min(
-            small_cell_w / elf_img.get_width(),
-            small_cell_h / elf_img.get_height(),
-        )
-        elf_dims = (
-            elf_img.get_width() * elf_scale,
-            elf_img.get_height() * elf_scale,
-        )
-        elf_img = pygame.transform.scale(elf_img, elf_dims)
-        hole_img = pygame.transform.scale(self.hole_img, (cell_width, cell_height))
-        cracked_hole_img = pygame.transform.scale(
-            self.cracked_hole_img, (cell_width, cell_height)
-        )
-        ice_img = pygame.transform.scale(self.ice_img, (cell_width, cell_height))
-        goal_img = pygame.transform.scale(self.goal_img, (cell_width, cell_height))
-        start_img = pygame.transform.scale(self.start_img, (small_cell_w, small_cell_h))
+            self.elf_images = [
+                pygame.transform.scale(pygame.image.load(f_name), self.cell_size)
+                for f_name in elfs
+            ]
 
         desc = self.desc.tolist()
         assert isinstance(desc, list), f"desc should be a list or an array, got {desc}"
         for y in range(self.nrow):
             for x in range(self.ncol):
-                rect = (x * cell_width, y * cell_height, cell_width, cell_height)
+                pos = (x * self.cell_size[0], y * self.cell_size[1])
+                rect = (*pos, *self.cell_size)
+
+                self.window_surface.blit(self.ice_img, pos)
                 if desc[y][x] == b"H":
-                    self.window_surface.blit(hole_img, (rect[0], rect[1]))
+                    self.window_surface.blit(self.hole_img, pos)
                 elif desc[y][x] == b"G":
-                    self.window_surface.blit(ice_img, (rect[0], rect[1]))
-                    goal_rect = self._center_small_rect(rect, goal_img.get_size())
-                    self.window_surface.blit(goal_img, goal_rect)
+                    self.window_surface.blit(self.goal_img, pos)
                 elif desc[y][x] == b"S":
-                    self.window_surface.blit(ice_img, (rect[0], rect[1]))
-                    stool_rect = self._center_small_rect(rect, start_img.get_size())
-                    self.window_surface.blit(start_img, stool_rect)
-                else:
-                    self.window_surface.blit(ice_img, (rect[0], rect[1]))
+                    self.window_surface.blit(self.start_img, pos)
 
                 pygame.draw.rect(self.window_surface, (180, 200, 230), rect, 1)
 
         # paint the elf
         bot_row, bot_col = self.s // self.ncol, self.s % self.ncol
-        cell_rect = (
-            bot_col * cell_width,
-            bot_row * cell_height,
-            cell_width,
-            cell_height,
-        )
+        cell_rect = (bot_col * self.cell_size[0], bot_row * self.cell_size[1])
+        last_action = self.lastaction if self.lastaction is not None else 1
+        elf_img = self.elf_images[last_action]
+
         if desc[bot_row][bot_col] == b"H":
-            self.window_surface.blit(cracked_hole_img, (cell_rect[0], cell_rect[1]))
+            self.window_surface.blit(self.cracked_hole_img, cell_rect)
         else:
-            elf_rect = self._center_small_rect(cell_rect, elf_img.get_size())
-            self.window_surface.blit(elf_img, elf_rect)
+            self.window_surface.blit(elf_img, cell_rect)
 
         if mode == "human":
             pygame.event.pump()
             pygame.display.update()
             self.clock.tick(self.metadata["render_fps"])
-        elif mode in {"rgb_array", "single_rgb_array"}:
+        elif mode == "rgb_array":
             return np.transpose(
                 np.array(pygame.surfarray.pixels3d(self.window_surface)), axes=(1, 0, 2)
             )
