@@ -8,7 +8,6 @@ import numpy as np
 from gym import Env, spaces, utils
 from gym.envs.toy_text.utils import categorical_sample
 from gym.error import DependencyNotInstalled
-from gym.utils.renderer import Renderer
 
 MAP = [
     "+---------+",
@@ -89,7 +88,7 @@ class TaxiEnv(Env):
 
     ### Info
 
-    ``step`` and ``reset(return_info=True)`` will return an info dictionary that contains "p" and "action_mask" containing
+    ``step`` and ``reset()`` will return an info dictionary that contains "p" and "action_mask" containing
         the probability that the state is taken and a mask of what actions will result in a change of state to speed up training.
 
     As Taxi's initial state is a stochastic, the "p" key represents the probability of the
@@ -122,7 +121,7 @@ class TaxiEnv(Env):
     """
 
     metadata = {
-        "render_modes": ["human", "ansi", "rgb_array", "single_rgb_array"],
+        "render_modes": ["human", "ansi", "rgb_array"],
         "render_fps": 4,
     }
 
@@ -192,7 +191,6 @@ class TaxiEnv(Env):
         self.observation_space = spaces.Discrete(num_states)
 
         self.render_mode = render_mode
-        self.renderer = Renderer(self.render_mode, self._render)
 
         # pygame utils
         self.window = None
@@ -259,39 +257,31 @@ class TaxiEnv(Env):
         p, s, r, t = transitions[i]
         self.s = s
         self.lastaction = a
-        self.renderer.render_step()
+
+        if self.render_mode == "human":
+            self.render()
         return (int(s), r, t, False, {"prob": p, "action_mask": self.action_mask(s)})
 
     def reset(
         self,
         *,
         seed: Optional[int] = None,
-        return_info: bool = False,
         options: Optional[dict] = None,
     ):
         super().reset(seed=seed)
         self.s = categorical_sample(self.initial_state_distrib, self.np_random)
         self.lastaction = None
         self.taxi_orientation = 0
-        self.renderer.reset()
-        self.renderer.render_step()
-        if not return_info:
-            return int(self.s)
-        else:
-            return int(self.s), {"prob": 1.0, "action_mask": self.action_mask(self.s)}
 
-    def render(self, mode="human"):
-        if self.render_mode is not None:
-            return self.renderer.get_renders()
-        else:
-            return self._render(mode)
+        if self.render_mode == "human":
+            self.render()
+        return int(self.s), {"prob": 1.0, "action_mask": self.action_mask(self.s)}
 
-    def _render(self, mode):
-        assert mode in self.metadata["render_modes"]
-        if mode == "ansi":
+    def render(self):
+        if self.render_mode == "ansi":
             return self._render_text()
-        elif mode in {"human", "rgb_array", "single_rgb_array"}:
-            return self._render_gui(mode)
+        else:  # self.render_mode in {"human", "rgb_array"}:
+            return self._render_gui(self.render_mode)
 
     def _render_gui(self, mode):
         try:
@@ -306,7 +296,7 @@ class TaxiEnv(Env):
             pygame.display.set_caption("Taxi")
             if mode == "human":
                 self.window = pygame.display.set_mode(WINDOW_SIZE)
-            elif mode in {"rgb_array", "single_rgb_array"}:
+            elif mode == "rgb_array":
                 self.window = pygame.Surface(WINDOW_SIZE)
 
         assert (
@@ -418,7 +408,7 @@ class TaxiEnv(Env):
         if mode == "human":
             pygame.display.update()
             self.clock.tick(self.metadata["render_fps"])
-        elif mode in {"rgb_array", "single_rgb_array"}:
+        elif mode == "rgb_array":
             return np.transpose(
                 np.array(pygame.surfarray.pixels3d(self.window)), axes=(1, 0, 2)
             )
